#!/bin/sh
# Licensed Materials - Property of IBM
# Rational ClearQuest 
# (C) Copyright IBM Corp. 2013 All Rights Reserved
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#
# Run this batch file to copy the Eclipse plugins of the reporting driver from the shared Installation
# Manager directory to a target directory
# Usage:   
#  deployBIRT <no arguments>   - Deploy "birt.war" to the default WebSphere Application Server profile, customize the settings
#  for usage with ClearQuest, and copy the ClearQuest Reporting Driver files.
#  deployBIRT <war_file> - Deploy the passed birt war file to default WebSphere Application Server profile,  customize the settings
#  for usage with ClearQuest, and copy the ClearQuest Reporting Driver files.

usage()
{
set echo
echo deployBIRT usage:
echo    deployBIRT war_file
echo       Deploy the passed birt war file to default WebSphere Application Server profile, customize the settings for usage with ClearQuest, and copy the ClearQuest Reporting Driver files.
unset echo
exit 0
}

# Initialize settings used during script processing.
# PLUGIN_PATH can be changed if a nondefault installation path is used
initializeSettings()
{
# WAS_PROFILE_PATH=/opt/IBM/WebSphere/AppServer/profiles/AppSrv01
# WAS_PROFILE_PATH=/opt/rational/clearquest/cqweb/cqwebprofile
WAS_PROFILE_PATH=ADD_WAS_PROFILE_PATH_HERE
BIRT_DRIVER_PATH=
WAR_FILE=
}


# Clear settings established by initializeSettings
clearSettings()
{
unset WAS_PROFILE_PATH
unset BIRT_DRIVER_PATH
unset WAR_FILE
}

configureWASForJNI()
{
echo Calling wsadmin to run script cq_setup.py for configuring JNI report execution
$WAS_PROFILE_PATH/bin/wsadmin.sh -lang jython -f cq_setup.py
}

deployBIRT()
{
if ( ! [ -f $WAR_FILE ]); then
   echo ERROR:  The file $WAR_FILE does not exist.  Exiting..
   exit 0
fi
if ( ! [ -d $WAS_PROFILE_PATH ]); then
   echo ERROR:  The WebSphere profile path $WAS_PROFILE_PATH does not exist.  Exiting..
   exit 0
fi


echo Calling wsadmin to deploy $WAR_FILE
$WAS_PROFILE_PATH/bin/wsadmin.sh -lang jython -f deployBIRT.py $WAR_FILE -wsadmin_classpath ./deployBIRT.jar
if [ "$BIRT_DRIVER_PATH" = "" ]; then 
   setDefaultBIRTPath
fi
copyDriverPlugins
}

copyDriverPlugins()
{
echo Calling ./copyDriverPlugins.sh with target path $BIRT_DRIVER_PATH
./copyDriverPlugins.sh $BIRT_DRIVER_PATH
}

setDefaultBIRTPath()
{
local tempPath=$WAS_PROFILE_PATH/installedApps/dfltCell/birt_war.ear/$WAR_FILE/WEB-INF
if [ -d $tempPath/platform ]; then
   BIRT_DRIVER_PATH=$tempPath/platform/plugins
else
   BIRT_DRIVER_PATH=$tempPath/lib
fi
}


if [ "$1" = "usage" ]; then usage
exit 0
fi

initializeSettings
if [ $# -eq 0 ]; then 
   WAR_FILE=birt.war
else
   WAR_FILE=$1
fi


deployBIRT

# Next operation configures WebSphere so that it can find required ClearQuest resources for running
# reports that use JNI data sources
configureWASForJNI
exit 0
